@@ -1,6 +1,6 @@
 use santiago::grammar::Grammar;
 
-pub fn grammar() -> Grammar {
+pub fn grammar() -> Grammar<()> {
     santiago::grammar!(
         // A string in the form: `str_content`
         "string" => rules "string_start" "str_content" "string_end";
@@ -13,9 +13,9 @@ pub fn grammar() -> Grammar {
         "str_content" => rules "str_content" "var";
 
         // Map rules to their corresponding Lexemes
-        "str" => lexeme "STR";
-        "string_start" => lexeme "STRING_START";
-        "string_end" => lexeme "STRING_END";
-        "var" => lexeme "VAR";
+        "str" => lexemes "STR";
+        "string_start" => lexemes "STRING_START";
+        "string_end" => lexemes "STRING_END";
+        "var" => lexemes "VAR";
     )
 }
