@@ -4,9 +4,9 @@
 
 mod ambiguous_integer_addition;
 mod calculator;
-mod calculator_with_value;
+mod calculator_with_ast;
 mod integer_addition;
-mod integer_addition_with_value;
+mod integer_addition_with_ast;
 mod javascript_string_interpolation;
 mod nix;
 mod smallest;
@@ -32,11 +32,11 @@ fn calculator() {
 }
 
 #[test]
-fn calculator_with_value() {
+fn calculator_with_ast() {
     run(
-        "calculator_with_value",
-        &calculator_with_value::lexer::lexer_rules(),
-        &calculator_with_value::grammar::grammar(),
+        "calculator_with_ast",
+        &calculator_with_ast::lexer::lexer_rules(),
+        &calculator_with_ast::grammar::grammar(),
         true,
     );
 }
@@ -62,11 +62,11 @@ fn integer_addition() {
 }
 
 #[test]
-fn integer_addition_with_value() {
+fn integer_addition_with_ast() {
     run(
-        "integer_addition_with_value",
-        &integer_addition_with_value::lexer::lexer_rules(),
-        &integer_addition_with_value::grammar::grammar(),
+        "integer_addition_with_ast",
+        &integer_addition_with_ast::lexer::lexer_rules(),
+        &integer_addition_with_ast::grammar::grammar(),
         true,
     );
 }
@@ -90,7 +90,7 @@ fn run<AST>(
     name: &str,
     lexer_rules: &santiago::lexer::LexerRules,
     grammar: &santiago::grammar::Grammar<AST>,
-    test_values: bool,
+    test_ast: bool,
 ) where
     AST: std::fmt::Debug,
 {
@@ -110,7 +110,7 @@ fn run<AST>(
         let path_lexemes = format!("{cases_dir}/{case}/lexemes");
         let path_earley = format!("{cases_dir}/{case}/earley");
         let path_parse_trees = format!("{cases_dir}/{case}/parse_trees");
-        let path_values = format!("{cases_dir}/{case}/values");
+        let path_asts = format!("{cases_dir}/{case}/asts");
 
         let input = std::fs::read_to_string(&path_input)
             .unwrap()
@@ -173,14 +173,14 @@ fn run<AST>(
             std::fs::read_to_string(&path_parse_trees).unwrap()
         );
 
-        if test_values {
-            let values: Vec<AST> = parse_trees
+        if test_ast {
+            let ast: Vec<AST> = parse_trees
                 .iter()
                 .map(|parse_tree| parse_tree.as_abstract_syntax_tree())
                 .collect();
-            let values_str: String = values
+            let ast_str: String = ast
                 .iter()
-                .map(|parse_tree| format!("---\n{parse_tree:?}"))
+                .map(|ast| format!("---\n{ast:#?}"))
                 .collect::<String>()
                 .lines()
                 .collect::<Vec<&str>>()
@@ -188,16 +188,13 @@ fn run<AST>(
 
             #[cfg(not(tarpaulin))]
             if should_update {
-                std::fs::File::create(&path_values)
+                std::fs::File::create(&path_asts)
                     .unwrap()
-                    .write_all(values_str.as_bytes())
+                    .write_all(ast_str.as_bytes())
                     .unwrap();
             }
 
-            assert_eq!(
-                values_str,
-                std::fs::read_to_string(&path_values).unwrap()
-            );
+            assert_eq!(ast_str, std::fs::read_to_string(&path_asts).unwrap());
         }
     }
 }
